from setuptools import setup

setup(name='gaussian-compute',
      version='0.1',
      description='Python package for Gaussian distributions',
      packages=['gaussian-compute'],
      zip_safe=False)
